==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_web_acl/Wafv2WebAclRuleActionCaptcha.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_web_acl;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:56.191Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2WebAcl.Wafv2WebAclRuleActionCaptcha")
@software.amazon.jsii.Jsii.Proxy(Wafv2WebAclRuleActionCaptcha.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Wafv2WebAclRuleActionCaptcha extends software.amazon.jsii.JsiiSerializable {

    /**
     * custom_request_handling block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/wafv2_web_acl#custom_request_handling Wafv2WebAcl#custom_request_handling}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling getCustomRequestHandling() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Wafv2WebAclRuleActionCaptcha> {
        com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling;

        /**
         * Sets the value of {@link Wafv2WebAclRuleActionCaptcha#getCustomRequestHandling}
         * @param customRequestHandling custom_request_handling block.
         *                              Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/wafv2_web_acl#custom_request_handling Wafv2WebAcl#custom_request_handling}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customRequestHandling(com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling) {
            this.customRequestHandling = customRequestHandling;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Wafv2WebAclRuleActionCaptcha}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Wafv2WebAclRuleActionCaptcha build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Wafv2WebAclRuleActionCaptcha {
        private final com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.customRequestHandling = software.amazon.jsii.Kernel.get(this, "customRequestHandling", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.customRequestHandling = builder.customRequestHandling;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling getCustomRequestHandling() {
            return this.customRequestHandling;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCustomRequestHandling() != null) {
                data.set("customRequestHandling", om.valueToTree(this.getCustomRequestHandling()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.wafv2WebAcl.Wafv2WebAclRuleActionCaptcha"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Wafv2WebAclRuleActionCaptcha.Jsii$Proxy that = (Wafv2WebAclRuleActionCaptcha.Jsii$Proxy) o;

            return this.customRequestHandling != null ? this.customRequestHandling.equals(that.customRequestHandling) : that.customRequestHandling == null;
        }

        @Override
        public final int hashCode() {
            int result = this.customRequestHandling != null ? this.customRequestHandling.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/wafv2_web_acl/Wafv2WebAclRuleActionCaptcha.java <==
package com.hashicorp.cdktf.providers.aws.wafv2_web_acl;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.960Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.wafv2WebAcl.Wafv2WebAclRuleActionCaptcha")
@software.amazon.jsii.Jsii.Proxy(Wafv2WebAclRuleActionCaptcha.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Wafv2WebAclRuleActionCaptcha extends software.amazon.jsii.JsiiSerializable {

    /**
     * custom_request_handling block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_web_acl#custom_request_handling Wafv2WebAcl#custom_request_handling}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling getCustomRequestHandling() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Wafv2WebAclRuleActionCaptcha> {
        com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling;

        /**
         * Sets the value of {@link Wafv2WebAclRuleActionCaptcha#getCustomRequestHandling}
         * @param customRequestHandling custom_request_handling block.
         *                              Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/wafv2_web_acl#custom_request_handling Wafv2WebAcl#custom_request_handling}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customRequestHandling(com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling) {
            this.customRequestHandling = customRequestHandling;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Wafv2WebAclRuleActionCaptcha}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Wafv2WebAclRuleActionCaptcha build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Wafv2WebAclRuleActionCaptcha}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Wafv2WebAclRuleActionCaptcha {
        private final com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling customRequestHandling;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.customRequestHandling = software.amazon.jsii.Kernel.get(this, "customRequestHandling", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.customRequestHandling = builder.customRequestHandling;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.wafv2_web_acl.Wafv2WebAclRuleActionCaptchaCustomRequestHandling getCustomRequestHandling() {
            return this.customRequestHandling;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCustomRequestHandling() != null) {
                data.set("customRequestHandling", om.valueToTree(this.getCustomRequestHandling()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.wafv2WebAcl.Wafv2WebAclRuleActionCaptcha"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Wafv2WebAclRuleActionCaptcha.Jsii$Proxy that = (Wafv2WebAclRuleActionCaptcha.Jsii$Proxy) o;

            return this.customRequestHandling != null ? this.customRequestHandling.equals(that.customRequestHandling) : that.customRequestHandling == null;
        }

        @Override
        public final int hashCode() {
            int result = this.customRequestHandling != null ? this.customRequestHandling.hashCode() : 0;
            return result;
        }
    }
}
